#!/bin/sh

if [ -n "$EH_PREFIX" ]; then
	export PREFIX="$EH_PREFIX"
fi

if [ -z "$PREFIX" ]; then
	echo "ERROR: set \$PREFIX before sourcing this script!"
	exit 1
fi

SW_VERSION=`sw_vers -productVersion | cut -d. -f1-2`
case $SW_VERSION in
	10.[01])
		echo "unsupported OS version: $SW_VERSION"
		exit 1
		;;
	10.2)
		export MACOSX_DEPLOYMENT_TARGET=10.2
		FREETYPE_CONFIG=$PREFIX/bin/freetype-config
		export EH_USE_CACHE=0
		;;
	10.[34])
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
	*)
		export EH_USE_CACHE=0
		export MACOSX_DEPLOYMENT_TARGET="$SW_VERSION"
		export LD_TWOLEVEL_NAMESPACE=true
		FREETYPE_CONFIG=$PREFIX/lib/freetype219/bin/freetype-config
		;;
esac

LDFLAGS=""

if [ -n "$USE_UNSERMAKE" ] && [ "$USE_UNSERMAKE" -gt 0 ]; then
	MAKEFLAGS=`echo $MAKEFLAGS | sed -e 's,-j,-j1 --compile-jobs=,'`
fi

#for dir in freetype2 xft2 render1 fontconfig2 xrender1 flex; do
for dir in system-openssl freetype219 fontconfig2 flex; do
	if [ -d "$PREFIX/lib/$dir" ]; then
		for incdir in "$PREFIX/lib/$dir/include/freetype2" "$PREFIX/lib/$dir/include"; do
			if [ -d "$incdir" ]; then
				export CPPFLAGS="$CPPFLAGS -I$incdir"
			fi
		done
		[ -d "$PREFIX/lib/$dir/lib" ]           && export LDFLAGS="-L$PREFIX/lib/$dir/lib $LDFLAGS"
		[ -d "$PREFIX/lib/$dir/bin" ]           && export PATH="$PREFIX/lib/$dir/bin:$PATH"
		[ -d "$PREFIX/lib/$dir/lib/pkgconfig" ] && export PKG_CONFIG_PATH="$PREFIX/lib/$dir/lib/pkgconfig:$PKG_CONFIG_PATH"
	fi
done

# -fast, minus the unsafe bits
if [ -d "libltdl" ]; then
	export ACLOCALFLAGS="$ACLOCALFLAGS -I libltdl"
fi
export CFLAGS="-Os -fPIC"
export CXXFLAGS="$CFLAGS"
export CPPFLAGS="$CPPFLAGS -fno-common -no-cpp-precomp -DMACOSX -DARTS_NO_ALARM -I$PREFIX/include -I/usr/X11R6/include"
export FREETYPE_CONFIG
export LIBS="$LIBS -L$PREFIX/lib -L/usr/X11R6/lib"
export SED="sed"
export CONFIGURE_PARAMS="--includedir=$PREFIX/include --libdir=$PREFIX/lib --prefix=$PREFIX --with-extra-libs=$PREFIX/lib --with-extra-includes=$PREFIX/include --enable-mt --with-pic --enable-rpath --enable-shared=yes --enable-static=no --mandir=$PREFIX/share/man --with-xinerama --with-pam --disable-final --with-ssl-dir=/usr --with-ssl --disable-dependency-tracking --enable-gcc-hidden-visibility"

if [ -e "$PREFIX/lib/qt3/include" ]; then
	CONFIGURE_PARAMS="$CONFIGURE_PARAMS --with-qt-dir=$PREFIX/lib/qt3"
else
	CONFIGURE_PARAMS="$CONFIGURE_PARAMS --with-qt-dir=$PREFIX --with-qt-includes=$PREFIX/include/qt"
fi

PATH=`echo $PATH | perl -p -e 'for my $entry (split(/:/, $_)) { next if ($entry =~ m,^/usr/local,); push(@path, $entry) }; $_ = join(":", @path)'`
export PATH="$PATH:/usr/X11R6/bin"

export ALL_LIBRARIES="$LDFLAGS -L$PREFIX/lib -L/usr/X11R6/lib"

cat <<END
the following environment is being used:

  ACLOCALFLAGS:             $ACLOCALFLAGS
  CFLAGS:                   $CFLAGS
  CPPFLAGS:                 $CPPFLAGS
  CXXFLAGS:                 $CXXFLAGS
  FREETYPE_CONFIG:          $FREETYPE_CONFIG
  LDFLAGS:                  $LDFLAGS
  LIBS:                     $LIBS
  MACOSX_DEPLOYMENT_TARGET: $MACOSX_DEPLOYMENT_TARGET
  PATH:                     $PATH
  PKG_CONFIG_PATH:          $PKG_CONFIG_PATH

END

if [ "x$EH_USE_CACHE" = "x1" ]; then
	export ac_cv_c_compiler_gnu=yes
	export ac_cv_cxx_compiler_gnu=yes
	export ac_cv_exeext=
	export ac_cv_func__NSGetEnviron=yes
	export ac_cv_func_inet_ntoa=yes
	export ac_cv_func_inet_ntop=yes
	export ac_cv_func_inet_pton=yes
	export ac_cv_have_dlfcn=yes
	export ac_cv_header_Carbon_Carbon_h=yes
	export ac_cv_header_CoreAudio_CoreAudio_h=yes
	export ac_cv_header_crt_externs_h=yes
	export ac_cv_header_dlfcn_h=yes
	export ac_cv_header_sys_stat_h=yes
	export ac_cv_header_sys_types_h=yes
	export ac_cv_header_unistd_h=yes
	export ac_cv_lib_dl_dlopen=yes
	export ac_cv_lib_dld_shl_unload=no
	export ac_cv_lib_dnet_dnet_ntoa=no
	export ac_cv_lib_dnet_stub_dnet_ntoa=no
	export ac_cv_lib_jpeg_6b=no
	export ac_cv_lib_jpeg_normal=-ljpeg
	export ac_cv_lib_png='-lpng -lz -lm'
	export ac_cv_lib_poll_poll=yes
	export ac_cv_lib_pthread_pthread_create=yes
	export ac_cv_lib_z=-lz
	export ac_cv_objext=o
	export ac_cv_path_GMSGFMT=$PREFIX/bin/msgfmt
	export ac_cv_path_MSGFMT=$PREFIX/bin/msgfmt
	export ac_cv_path_XGETTEXT=$PREFIX/bin/xgettext
	export ac_cv_path_install='/usr/bin/install -c'
	export ac_cv_prog_ac_ct_AR=ar
	export ac_cv_prog_ac_ct_RANLIB=ranlib
	export ac_cv_prog_ac_ct_STRIP=strip
	export ac_cv_prog_egrep='grep -E'
	export ac_cv_prog_make_make_set=yes
	export ac_cv_type_int=yes
	export ac_cv_type_long=yes
	export ac_cv_type_short=yes
	export ac_cv_type_size_t=yes
	export ac_cv_type_unsigned_long=yes
fi
